public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
* [Patch] MdeModulePkg UefiBootManagerLib: Rename BootMenuApp to BootManagerMenuApp
@ 2016-08-31  8:19 Liming Gao
  2016-09-01  2:02 ` Ni, Ruiyu
  0 siblings, 1 reply; 2+ messages in thread
From: Liming Gao @ 2016-08-31  8:19 UTC (permalink / raw)
  To: edk2-devel; +Cc: Ruiyu Ni

Rename local function name BootMenuApp to BootManagerMenuApp to align
to other public function name.

Cc: Ruiyu Ni <ruiyu.ni@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Liming Gao <liming.gao@intel.com>
---
 MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c b/MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c
index f8a3988..88bb13b 100644
--- a/MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c
+++ b/MdeModulePkg/Library/UefiBootManagerLib/BmBoot.c
@@ -1530,15 +1530,15 @@ EfiBootManagerGetLoadOptionBuffer (
 }
 
 /**
-  Check if it's a Device Path pointing to BootMenuApp.
+  Check if it's a Device Path pointing to BootManagerMenuApp.
 
   @param  DevicePath     Input device path.
 
-  @retval TRUE   The device path is BootMenuApp File Device Path.
-  @retval FALSE  The device path is NOT BootMenuApp File Device Path.
+  @retval TRUE   The device path is BootManagerMenuApp File Device Path.
+  @retval FALSE  The device path is NOT BootManagerMenuApp File Device Path.
 **/
 BOOLEAN
-BmIsBootMenuAppFilePath (
+BmIsBootManagerMenuAppFilePath (
   EFI_DEVICE_PATH_PROTOCOL     *DevicePath
 )
 {
@@ -1645,7 +1645,7 @@ EfiBootManagerBoot (
   // 3. Signal the EVT_SIGNAL_READY_TO_BOOT event when we are about to load and execute
   //    the boot option.
   //
-  if (BmIsBootMenuAppFilePath (BootOption->FilePath)) {
+  if (BmIsBootManagerMenuAppFilePath (BootOption->FilePath)) {
     DEBUG ((EFI_D_INFO, "[Bds] Booting Boot Manager Menu.\n"));
     BmStopHotkeyService (NULL, NULL);
   } else {
@@ -2070,9 +2070,9 @@ BmEnumerateBootOptions (
          );
   for (Index = 0; Index < HandleCount; Index++) {
     //
-    // Ignore BootMenuApp. its boot option will be created by BmRegisterBootManagerMenu().
+    // Ignore BootManagerMenuApp. its boot option will be created by BmRegisterBootManagerMenu().
     //
-    if (BmIsBootMenuAppFilePath (DevicePathFromHandle (Handles[Index]))) {
+    if (BmIsBootManagerMenuAppFilePath (DevicePathFromHandle (Handles[Index]))) {
       continue;
     }
 
@@ -2212,7 +2212,7 @@ BmRegisterBootManagerMenu (
   DevicePath = NULL;
   Description = NULL;
   //
   // Try to find BootMenuApp from LoadFile protocol
   //
   gBS->LocateHandleBuffer (
          ByProtocol,
@@ -2222,7 +2222,7 @@ BmRegisterBootManagerMenu (
          &Handles
          );
   for (Index = 0; Index < HandleCount; Index++) {
-    if (BmIsBootMenuAppFilePath (DevicePathFromHandle (Handles[Index]))) {
+    if (BmIsBootManagerMenuAppFilePath (DevicePathFromHandle (Handles[Index]))) {
       DevicePath  = DuplicateDevicePath (DevicePathFromHandle (Handles[Index]));
       Description = BmGetBootDescription (Handles[Index]);
       break;
@@ -2331,7 +2331,7 @@ EfiBootManagerGetBootManagerMenu (
   BootOptions = EfiBootManagerGetLoadOptions (&BootOptionCount, LoadOptionTypeBoot);
 
   for (Index = 0; Index < BootOptionCount; Index++) {
-    if (BmIsBootMenuAppFilePath (BootOptions[Index].FilePath)) {
+    if (BmIsBootManagerMenuAppFilePath (BootOptions[Index].FilePath)) {
         Status = EfiBootManagerInitializeLoadOption (
                    BootOption,
                    BootOptions[Index].OptionNumber,
@@ -2212,7 +2212,7 @@ BmRegisterBootManagerMenu (
   Description = NULL;
   //
-  // Try to find BootMenuApp from LoadFile protocol
+  // Try to find BootManagerMenuApp from LoadFile protocol
   //
   gBS->LocateHandleBuffer (
-- 
2.8.0.windows.1



^ permalink raw reply related	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2016-09-01  2:02 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2016-08-31  8:19 [Patch] MdeModulePkg UefiBootManagerLib: Rename BootMenuApp to BootManagerMenuApp Liming Gao
2016-09-01  2:02 ` Ni, Ruiyu

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox